pys5p package
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pys5p.lib

Submodules
----------

pys5p.ckd\_io module
--------------------

.. automodule:: pys5p.ckd_io
   :members:
   :undoc-members:
   :show-inheritance:

pys5p.error\_propagation module
-------------------------------

.. automodule:: pys5p.error_propagation
   :members:
   :undoc-members:
   :show-inheritance:

pys5p.get\_data\_dir module
---------------------------

.. automodule:: pys5p.get_data_dir
   :members:
   :undoc-members:
   :show-inheritance:

pys5p.icm\_io module
--------------------

.. automodule:: pys5p.icm_io
   :members:
   :undoc-members:
   :show-inheritance:

pys5p.l1b\_io module
--------------------

.. automodule:: pys5p.l1b_io
   :members:
   :undoc-members:
   :show-inheritance:

pys5p.l1b\_patch module
-----------------------

.. automodule:: pys5p.l1b_patch
   :members:
   :undoc-members:
   :show-inheritance:

pys5p.lv2\_io module
--------------------

.. automodule:: pys5p.lv2_io
   :members:
   :undoc-members:
   :show-inheritance:

pys5p.ocm\_io module
--------------------

.. automodule:: pys5p.ocm_io
   :members:
   :undoc-members:
   :show-inheritance:

pys5p.rls module
----------------

.. automodule:: pys5p.rls
   :members:
   :undoc-members:
   :show-inheritance:

pys5p.s5p\_msm module
---------------------

.. automodule:: pys5p.s5p_msm
   :members:
   :undoc-members:
   :show-inheritance:

pys5p.swir\_region module
-------------------------

.. automodule:: pys5p.swir_region
   :members:
   :undoc-members:
   :show-inheritance:

pys5p.swir\_texp module
-----------------------

.. automodule:: pys5p.swir_texp
   :members:
   :undoc-members:
   :show-inheritance:

pys5p.version module
--------------------

.. automodule:: pys5p.version
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pys5p
   :members:
   :undoc-members:
   :show-inheritance:
